@@ -7,10 +7,10 @@ use std::{
     ptr,
 };
 
-use crate::driver::CslStringList;
+use crate::cpl::CslStringList;
 use crate::errors::*;
 use crate::raster::RasterCreationOption;
-use crate::utils::{_last_cpl_err, _last_null_pointer_err, _string};
+use crate::utils::{_last_cpl_err, _last_null_pointer_err, _path_to_c_string, _string};
 use crate::vector::sql;
 use crate::vector::Geometry;
 use crate::{
@@ -168,19 +168,22 @@ impl Dataset {
 
     /// Open a dataset at the given `path` with default
     /// options.
-    pub fn open(path: &Path) -> Result<Dataset> {
-        Self::open_ex(path, DatasetOptions::default())
+    pub fn open<P: AsRef<Path>>(path: P) -> Result<Dataset> {
+        Self::_open_ex(path.as_ref(), DatasetOptions::default())
     }
 
     /// Open a dataset with extended options. See
     /// [`GDALOpenEx`].
     ///
     /// [`GDALOpenEx`]: https://gdal.org/doxygen/gdal_8h.html#a9cb8585d0b3c16726b08e25bcc94274a
-    pub fn open_ex(path: &Path, options: DatasetOptions) -> Result<Dataset> {
+    pub fn open_ex<P: AsRef<Path>>(path: P, options: DatasetOptions) -> Result<Dataset> {
+        Self::_open_ex(path.as_ref(), options)
+    }
+
+    fn _open_ex(path: &Path, options: DatasetOptions) -> Result<Dataset> {
         crate::driver::_register_drivers();
 
-        let filename = path.to_string_lossy();
-        let c_filename = CString::new(filename.as_ref())?;
+        let c_filename = _path_to_c_string(path)?;
         let c_open_flags = options.open_flags.bits;
 
         // handle driver params:
@@ -304,13 +307,22 @@ impl Dataset {
         Ok(())
     }
 
-    pub fn create_copy(
+    pub fn create_copy<P: AsRef<Path>>(
         &self,
         driver: &Driver,
-        filename: &str,
+        filename: P,
         options: &[RasterCreationOption],
     ) -> Result<Dataset> {
-        let c_filename = CString::new(filename)?;
+        Self::_create_copy(self, driver, filename.as_ref(), options)
+    }
+
+    fn _create_copy(
+        &self,
+        driver: &Driver,
+        filename: &Path,
+        options: &[RasterCreationOption],
+    ) -> Result<Dataset> {
+        let c_filename = _path_to_c_string(filename)?;
 
         let mut c_options = CslStringList::new();
         for option in options {
