@@ -1,13 +1,16 @@
+use std::ffi::CString;
+use std::path::Path;
+use std::sync::Once;
+
+use gdal_sys::{self, CPLErr, GDALDriverH, GDALMajorObjectH};
+use libc::c_int;
+
+use crate::cpl::CslStringList;
 use crate::dataset::Dataset;
 use crate::gdal_major_object::MajorObject;
 use crate::metadata::Metadata;
 use crate::raster::{GdalType, RasterCreationOption};
-use crate::utils::{_last_null_pointer_err, _string};
-use gdal_sys::{self, CSLSetNameValue, GDALDriverH, GDALMajorObjectH};
-use libc::{c_char, c_int};
-use std::ffi::CString;
-use std::ptr::null_mut;
-use std::sync::Once;
+use crate::utils::{_last_cpl_err, _last_null_pointer_err, _path_to_c_string, _string};
 
 use crate::errors::*;
 
@@ -63,30 +66,48 @@ impl Driver {
         _string(rv)
     }
 
-    pub fn create(
+    pub fn create<P: AsRef<Path>>(
         &self,
-        filename: &str,
+        filename: P,
         size_x: isize,
         size_y: isize,
         bands: isize,
     ) -> Result<Dataset> {
-        self.create_with_band_type::<u8>(filename, size_x, size_y, bands)
+        self.create_with_band_type::<u8, _>(filename, size_x, size_y, bands)
     }
 
-    pub fn create_with_band_type<T: GdalType>(
+    pub fn create_with_band_type<T: GdalType, P: AsRef<Path>>(
         &self,
-        filename: &str,
+        filename: P,
         size_x: isize,
         size_y: isize,
         bands: isize,
     ) -> Result<Dataset> {
         let options = [];
-        self.create_with_band_type_with_options::<T>(filename, size_x, size_y, bands, &options)
+        self.create_with_band_type_with_options::<T, _>(filename, size_x, size_y, bands, &options)
     }
 
-    pub fn create_with_band_type_with_options<T: GdalType>(
+    pub fn create_with_band_type_with_options<T: GdalType, P: AsRef<Path>>(
         &self,
-        filename: &str,
+        filename: P,
+        size_x: isize,
+        size_y: isize,
+        bands: isize,
+        options: &[RasterCreationOption],
+    ) -> Result<Dataset> {
+        Self::_create_with_band_type_with_options::<T>(
+            self,
+            filename.as_ref(),
+            size_x,
+            size_y,
+            bands,
+            options,
+        )
+    }
+
+    fn _create_with_band_type_with_options<T: GdalType>(
+        &self,
+        filename: &Path,
         size_x: isize,
         size_y: isize,
         bands: isize,
@@ -97,7 +118,7 @@ impl Driver {
             options_c.set_name_value(option.key, option.value)?;
         }
 
-        let c_filename = CString::new(filename)?;
+        let c_filename = _path_to_c_string(filename)?;
         let c_dataset = unsafe {
             gdal_sys::GDALCreate(
                 self.c_driver,
@@ -117,8 +138,63 @@ impl Driver {
         Ok(unsafe { Dataset::from_c_dataset(c_dataset) })
     }
 
-    pub fn create_vector_only(&self, filename: &str) -> Result<Dataset> {
-        self.create_with_band_type::<u8>(filename, 0, 0, 0)
+    pub fn create_vector_only<P: AsRef<Path>>(&self, filename: P) -> Result<Dataset> {
+        self.create_with_band_type::<u8, _>(filename, 0, 0, 0)
+    }
+
+    /// Delete named dataset.
+    ///
+    /// It is unwise to have open dataset handles on this dataset when it is deleted.
+    ///
+    /// Calls `GDALDeleteDataset()`
+    ///
+    pub fn delete<P: AsRef<Path>>(&self, filename: P) -> Result<()> {
+        Self::_delete(self, filename.as_ref())
+    }
+
+    fn _delete(&self, filename: &Path) -> Result<()> {
+        let c_filename = _path_to_c_string(filename)?;
+
+        let rv = unsafe { gdal_sys::GDALDeleteDataset(self.c_driver, c_filename.as_ptr()) };
+
+        if rv != CPLErr::CE_None {
+            return Err(_last_cpl_err(rv));
+        }
+
+        Ok(())
+    }
+
+    /// Rename a dataset.
+    ///
+    /// It is unwise to have open dataset handles on this dataset when it is being renamed.
+    ///
+    /// Calls `GDALRenameDataset()`
+    ///
+    pub fn rename<P1: AsRef<Path>, P2: AsRef<Path>>(
+        &self,
+        new_filename: P1,
+        old_filename: P2,
+    ) -> Result<()> {
+        Self::_rename(self, new_filename.as_ref(), old_filename.as_ref())
+    }
+
+    fn _rename(&self, new_filename: &Path, old_filename: &Path) -> Result<()> {
+        let c_old_filename = _path_to_c_string(old_filename)?;
+        let c_new_filename = _path_to_c_string(new_filename)?;
+
+        let rv = unsafe {
+            gdal_sys::GDALRenameDataset(
+                self.c_driver,
+                c_new_filename.as_ptr(),
+                c_old_filename.as_ptr(),
+            )
+        };
+
+        if rv != CPLErr::CE_None {
+            return Err(_last_cpl_err(rv));
+        }
+
+        Ok(())
     }
 }
 
@@ -129,40 +205,3 @@ impl MajorObject for Driver {
 }
 
 impl Metadata for Driver {}
-
-/// Wraps a `char **papszStrList` pointer into a struct that
-/// automatically destroys the allocated memory on `drop`.
-pub struct CslStringList {
-    list_ptr: *mut *mut c_char,
-}
-
-impl CslStringList {
-    pub fn new() -> Self {
-        Self {
-            list_ptr: null_mut(),
-        }
-    }
-
-    /// Assign `value` to `name` in StringList.
-    /// Overrides duplicate `name`s.
-    pub fn set_name_value(&mut self, name: &str, value: &str) -> Result<()> {
-        let psz_name = CString::new(name)?;
-        let psz_value = CString::new(value)?;
-
-        unsafe {
-            self.list_ptr = CSLSetNameValue(self.list_ptr, psz_name.as_ptr(), psz_value.as_ptr());
-        }
-
-        Ok(())
-    }
-
-    pub fn as_ptr(&self) -> gdal_sys::CSLConstList {
-        self.list_ptr
-    }
-}
-
-impl Drop for CslStringList {
-    fn drop(&mut self) {
-        unsafe { gdal_sys::CSLDestroy(self.list_ptr) }
-    }
-}
