@@ -146,6 +146,29 @@ fn test_write_raster() {
     assert_eq!(right.data[0], 20u8);
 }
 
+#[test]
+fn test_rename_remove_raster() {
+    let dataset = Dataset::open(fixture!("tinymarble.tif")).unwrap();
+
+    let mem_file_path_a = Path::new("/vsimem/030bd1d1-8955-4604-8e37-177dade13863");
+    let mem_file_path_b = Path::new("/vsimem/c7bfce32-2474-48fa-a907-2af95f83c824");
+
+    let driver = Driver::get("GTiff").unwrap();
+
+    dataset.create_copy(&driver, &mem_file_path_a, &[]).unwrap();
+
+    driver.rename(mem_file_path_b, mem_file_path_a).unwrap();
+
+    // old dataset path is gone
+    assert!(Dataset::open(mem_file_path_a).is_err());
+    // dataset exists under new name
+    Dataset::open(mem_file_path_b).unwrap();
+
+    driver.delete(mem_file_path_b).unwrap();
+
+    assert!(Dataset::open(mem_file_path_b).is_err());
+}
+
 #[test]
 fn test_get_dataset_driver() {
     let dataset = Dataset::open(fixture!("tinymarble.png")).unwrap();
@@ -245,7 +268,9 @@ fn test_create() {
 #[test]
 fn test_create_with_band_type() {
     let driver = Driver::get("MEM").unwrap();
-    let dataset = driver.create_with_band_type::<f32>("", 10, 20, 3).unwrap();
+    let dataset = driver
+        .create_with_band_type::<f32, _>("", 10, 20, 3)
+        .unwrap();
     assert_eq!(dataset.raster_size(), (10, 20));
     assert_eq!(dataset.raster_count(), 3);
     assert_eq!(dataset.driver().short_name(), "MEM");
@@ -282,7 +307,7 @@ fn test_create_with_band_type_with_options() {
     let tmp_filename = "/tmp/test.tif";
     {
         let dataset = driver
-            .create_with_band_type_with_options::<u8>(tmp_filename, 256, 256, 1, &options)
+            .create_with_band_type_with_options::<u8, _>(tmp_filename, 256, 256, 1, &options)
             .unwrap();
         let rasterband = dataset.rasterband(1).unwrap();
         let block_size = rasterband.block_size();
