@@ -325,7 +325,6 @@ mod tests {
     }
 
     #[test]
-    #[cfg(feature = "datetime")]
     fn test_get_field_as_datetime() {
         use chrono::{FixedOffset, TimeZone};
 
@@ -632,7 +631,7 @@ mod tests {
         {
             let driver = Driver::get("GeoJSON").unwrap();
             let mut ds = driver
-                .create_vector_only(&fixture!("output.geojson").to_string_lossy())
+                .create_vector_only(&fixture!("output.geojson"))
                 .unwrap();
             let mut layer = ds.create_layer(Default::default()).unwrap();
             layer
